def remove_whitespace(text: str) -> str:
    """Removes any whitespace in a string and returns the string without any whitespace

    Args:
        text (str): the input string
    
    Returns:
       str: the new string that does not contain any whitespace
    """
    return text.replace(" ", "")

